# README

# Install

## GitHub

Simply start by downloading the repo to the local by either:

- Downloading the zip file
- Using `git` in the machine's command line

```shell
git clone https://github.com/mhbl3/adopt_pytorch.git
```

Then, navigate to the `adopt_pytorch` directory and install using `setup.py`

```shell
[current_dir: cd ../adopt_pytorch
current_dir/../adopt_pytorch: pip install ./
```

## Pypi

The package can also be downloaded using **Pypi**

```shell
pip install adopt_pytorch
```

